#include "hal_data.h"
#include "debug_bsp_uart.h"
#include "adc.h"

uint16_t adc_data = 0;
FSP_CPP_HEADER
void R_BSP_WarmStart(bsp_warm_start_event_t event);
FSP_CPP_FOOTER

/*******************************************************************************************************************/ /**
                                                                                                                       * main() is generated by the RA Configuration editor and is used to generate threads if an RTOS is used.  This function
                                                                                                                       * is called by main() when no RTOS is used.
                                                                                                                       **********************************************************************************************************************/
void hal_entry(void)
{
    /* TODO: add your own code here */
    typedef enum
    {
        up,
        down
    } Direction;
    Direction d = up;
    uint16_t dac_value = 0;
    Debug_UART9_Init(); // SCI9 UART 调试串口初始化
    g_dac0.p_api->open(&g_dac0_ctrl, &g_dac0_cfg);
    g_dac0.p_api->start(&g_dac0_ctrl);

    g_adc0.p_api->open(&g_adc0_ctrl, &g_adc0_cfg);
    g_adc0.p_api->scanCfg(&g_adc0_ctrl, &g_adc0_channel_cfg);
    while (1)
    {
        g_dac0.p_api->write(&g_dac0_ctrl, dac_value);
        g_adc0.p_api->scanStart(&g_adc0_ctrl);
        adc0_waitComplete();
        g_adc0.p_api->read(&g_adc0_ctrl, ADC_CHANNEL_0, &adc_data);
        double volt = (double)(adc_data / 4095.0) * 3.3;
        printf("adc_data: %d, 电压: %.3lf V\n", adc_data, volt);
        if (d == up)
        {
            dac_value += 500;
        }
        else
        {
            dac_value -= 500;
        }
        if (dac_value >= 4000)
        {
            d = down;
        }
        if (dac_value == 0)
        {
            d = up;
        }
        R_BSP_SoftwareDelay(200, BSP_DELAY_UNITS_MILLISECONDS);
    }
#if BSP_TZ_SECURE_BUILD
    /* Enter non-secure code */
    R_BSP_NonSecureEnter();
#endif
}

/*******************************************************************************************************************/ /**
                                                                                                                       * This function is called at various points during the startup process.  This implementation uses the event that is
                                                                                                                       * called right before main() to set up the pins.
                                                                                                                       *
                                                                                                                       * @param[in]  event    Where at in the start up process the code is currently at
                                                                                                                       **********************************************************************************************************************/
void R_BSP_WarmStart(bsp_warm_start_event_t event)
{
    if (BSP_WARM_START_RESET == event)
    {
#if BSP_FEATURE_FLASH_LP_VERSION != 0

        /* Enable reading from data flash. */
        R_FACI_LP->DFLCTL = 1U;

        /* Would normally have to wait tDSTOP(6us) for data flash recovery. Placing the enable here, before clock and
         * C runtime initialization, should negate the need for a delay since the initialization will typically take more than 6us. */
#endif
    }

    if (BSP_WARM_START_POST_C == event)
    {
        /* C runtime environment and system clocks are setup. */

        /* Configure pins. */
        R_IOPORT_Open(&IOPORT_CFG_CTRL, &IOPORT_CFG_NAME);

#if BSP_CFG_SDRAM_ENABLED

        /* Setup SDRAM and initialize it. Must configure pins first. */
        R_BSP_SdramInit(true);
#endif
    }
}

#if BSP_TZ_SECURE_BUILD

FSP_CPP_HEADER
BSP_CMSE_NONSECURE_ENTRY void template_nonsecure_callable();

/* Trustzone Secure Projects require at least one nonsecure callable function in order to build (Remove this if it is not required to build). */
BSP_CMSE_NONSECURE_ENTRY void template_nonsecure_callable()
{
}
FSP_CPP_FOOTER

#endif
